@@ -1,7 +1,5 @@
 //! Unix-only extensions, for sending signals.
 
-extern crate libc;
-
 use std::io;
 
 pub trait SharedChildExt {
@@ -30,11 +28,10 @@ impl SharedChildExt for super::SharedChild {
 
 #[cfg(test)]
 mod tests {
-    use super::libc;
     use super::SharedChildExt;
+    use crate::tests::*;
+    use crate::SharedChild;
     use std::os::unix::process::ExitStatusExt;
-    use tests::*;
-    use SharedChild;
 
     #[test]
     fn test_send_signal() {
